diff --git a/GMW/GMW/Web.config b/GMW/GMW/Web.config
index f7f99248..8bb10194 100644
--- a/GMW/GMW/Web.config
+++ b/GMW/GMW/Web.config
@@ -62,7 +62,7 @@
-
+
diff --git a/GMW/GMW/bin/GMW.dll b/GMW/GMW/bin/GMW.dll
index b72a306f..6304d6bd 100644
Binary files a/GMW/GMW/bin/GMW.dll and b/GMW/GMW/bin/GMW.dll differ
diff --git a/GMW/GMW/bin/GMW_data.dll b/GMW/GMW/bin/GMW_data.dll
index cb685f31..ad90eccf 100644
Binary files a/GMW/GMW/bin/GMW_data.dll and b/GMW/GMW/bin/GMW_data.dll differ
diff --git a/GMW/GMW/mazzAppSettings.config b/GMW/GMW/mazzAppSettings.config
index f462cae7..3fb97f24 100644
--- a/GMW/GMW/mazzAppSettings.config
+++ b/GMW/GMW/mazzAppSettings.config
@@ -7,7 +7,7 @@
-
+
diff --git a/GMW/GMW/obj/Debug/GMW.dll b/GMW/GMW/obj/Debug/GMW.dll
index f982d21a..6304d6bd 100644
Binary files a/GMW/GMW/obj/Debug/GMW.dll and b/GMW/GMW/obj/Debug/GMW.dll differ
diff --git a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache
index c25610b2..d4670f97 100644
Binary files a/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_Term/Web.config b/GMW/GMW_Term/Web.config
index 15e82c48..3273666e 100644
--- a/GMW/GMW_Term/Web.config
+++ b/GMW/GMW_Term/Web.config
@@ -58,7 +58,7 @@
-
+
diff --git a/GMW/GMW_Term/bin/GMW_Term.dll b/GMW/GMW_Term/bin/GMW_Term.dll
index e1899a60..ad1bca9b 100644
Binary files a/GMW/GMW_Term/bin/GMW_Term.dll and b/GMW/GMW_Term/bin/GMW_Term.dll differ
diff --git a/GMW/GMW_Term/bin/GMW_data.dll b/GMW/GMW_Term/bin/GMW_data.dll
index 902d1700..ad90eccf 100644
Binary files a/GMW/GMW_Term/bin/GMW_data.dll and b/GMW/GMW_Term/bin/GMW_data.dll differ
diff --git a/GMW/GMW_Term/mazzAppSettings.config b/GMW/GMW_Term/mazzAppSettings.config
index f851af71..413375b9 100644
--- a/GMW/GMW_Term/mazzAppSettings.config
+++ b/GMW/GMW_Term/mazzAppSettings.config
@@ -7,7 +7,7 @@
-
+
diff --git a/GMW/GMW_Term/obj/Debug/GMW_Term.dll b/GMW/GMW_Term/obj/Debug/GMW_Term.dll
index f5fc3d46..ad1bca9b 100644
Binary files a/GMW/GMW_Term/obj/Debug/GMW_Term.dll and b/GMW/GMW_Term/obj/Debug/GMW_Term.dll differ
diff --git a/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache
index 9156c646..6c85663b 100644
Binary files a/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW_Term/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_Term_installer/GMW_Term_installer.vdproj b/GMW/GMW_Term_installer/GMW_Term_installer.vdproj
index a23a964b..a7c6af65 100644
--- a/GMW/GMW_Term_installer/GMW_Term_installer.vdproj
+++ b/GMW/GMW_Term_installer/GMW_Term_installer.vdproj
@@ -330,14 +330,14 @@
{
"Name" = "8:Microsoft Visual Studio"
"ProductName" = "8:GMW_Term"
- "ProductCode" = "8:{BE3DD215-7264-4D73-A5D0-BF945DA31FC0}"
- "PackageCode" = "8:{A0EE4CB7-B344-41B2-A88B-E23FC88143BD}"
+ "ProductCode" = "8:{E89376FC-9029-41FD-8042-C9B3C96A4EB0}"
+ "PackageCode" = "8:{043B7D9C-CAB5-4598-B640-611FC4D10335}"
"UpgradeCode" = "8:{B348C50D-8DAD-4430-AEF0-60800C94CB78}"
"RestartWWWService" = "11:TRUE"
"RemovePreviousVersions" = "11:TRUE"
"DetectNewerInstalledVersion" = "11:TRUE"
"InstallAllUsers" = "11:FALSE"
- "ProductVersion" = "8:1.0.300"
+ "ProductVersion" = "8:1.0.305"
"Manufacturer" = "8:SteamWare s.r.l."
"ARPHELPTELEPHONE" = "8:+39-035460560"
"ARPHELPLINK" = "8:http://www.steamware.net"
diff --git a/GMW/GMW_data/GMW_data.csproj b/GMW/GMW_data/GMW_data.csproj
index dd1ce3e9..45fe3129 100644
--- a/GMW/GMW_data/GMW_data.csproj
+++ b/GMW/GMW_data/GMW_data.csproj
@@ -160,6 +160,7 @@
SettingsSingleFileGenerator
Settings.Designer.cs
+
diff --git a/GMW/GMW_data/SqlScripts/GMW_00305.sql b/GMW/GMW_data/SqlScripts/GMW_00305.sql
new file mode 100644
index 00000000..c9526b44
--- /dev/null
+++ b/GMW/GMW_data/SqlScripts/GMW_00305.sql
@@ -0,0 +1,6 @@
+
+
+
+-- registro versione...
+INSERT INTO [dbo].[LogUpdateDb] ([Versione],[Data]) VALUES(305, GETDATE())
+GO
diff --git a/GMW/GMW_data/bin/Debug/GMW_data.dll b/GMW/GMW_data/bin/Debug/GMW_data.dll
index 2d1a6c4b..ad90eccf 100644
Binary files a/GMW/GMW_data/bin/Debug/GMW_data.dll and b/GMW/GMW_data/bin/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/GMW_data.dll b/GMW/GMW_data/obj/Debug/GMW_data.dll
index 2d1a6c4b..ad90eccf 100644
Binary files a/GMW/GMW_data/obj/Debug/GMW_data.dll and b/GMW/GMW_data/obj/Debug/GMW_data.dll differ
diff --git a/GMW/GMW_data/obj/Debug/ResolveAssemblyReference.cache b/GMW/GMW_data/obj/Debug/ResolveAssemblyReference.cache
index 1b7fb689..3badb4c9 100644
Binary files a/GMW/GMW_data/obj/Debug/ResolveAssemblyReference.cache and b/GMW/GMW_data/obj/Debug/ResolveAssemblyReference.cache differ
diff --git a/GMW/GMW_installer/GMW_installer.vdproj b/GMW/GMW_installer/GMW_installer.vdproj
index e6338ed8..c9e007a0 100644
--- a/GMW/GMW_installer/GMW_installer.vdproj
+++ b/GMW/GMW_installer/GMW_installer.vdproj
@@ -349,14 +349,14 @@
{
"Name" = "8:Microsoft Visual Studio"
"ProductName" = "8:GMW"
- "ProductCode" = "8:{81F0FF2E-60CC-4D19-A9FF-9C45D7C243B0}"
- "PackageCode" = "8:{C862786F-9317-44F7-9041-369261413B3F}"
+ "ProductCode" = "8:{0EE54AA8-8216-4F3E-83FB-27585280D49B}"
+ "PackageCode" = "8:{8D64D621-0E56-4AA2-925D-3AB7B1523273}"
"UpgradeCode" = "8:{C9BC0732-DC92-4336-BAC9-A05A5D2A97C0}"
"RestartWWWService" = "11:TRUE"
"RemovePreviousVersions" = "11:TRUE"
"DetectNewerInstalledVersion" = "11:TRUE"
"InstallAllUsers" = "11:FALSE"
- "ProductVersion" = "8:1.0.300"
+ "ProductVersion" = "8:1.0.305"
"Manufacturer" = "8:SteamWare s.r.l."
"ARPHELPTELEPHONE" = "8:+39-035460560"
"ARPHELPLINK" = "8:http://www.steamware.net"
@@ -829,7 +829,7 @@
}
"{5259A561-127C-4D43-A0A1-72F10C7B3BF8}:_4FD0E5B75A7F47B79080EC0983BE6583"
{
- "SourcePath" = "8:..\\..\\SetDirectoryPermission\\obj\\Release\\SetDirectoryPermission.exe"
+ "SourcePath" = "8:..\\..\\SetDirectoryPermission\\obj\\Debug\\SetDirectoryPermission.exe"
"TargetName" = "8:"
"Tag" = "8:"
"Folder" = "8:_5606017201AE45B480A8ABD8B8D68264"
@@ -857,7 +857,7 @@
}
"{5259A561-127C-4D43-A0A1-72F10C7B3BF8}:_8BDD7AA9D46A46EC80880F83F13C902E"
{
- "SourcePath" = "8:..\\..\\IISCustomActionVB\\IISConsoleVB\\obj\\Release\\IISConsoleVB.exe"
+ "SourcePath" = "8:..\\..\\IISCustomActionVB\\IISConsoleVB\\obj\\Debug\\IISConsoleVB.exe"
"TargetName" = "8:"
"Tag" = "8:"
"Folder" = "8:_5606017201AE45B480A8ABD8B8D68264"
diff --git a/GMW/GMW_Term/WebUserControls/mod_btnUdc.ascx.cs b/GMW/GMW_Term/WebUserControls/mod_btnUdc.ascx.cs
index dbf2c5a1..c2004846 100644
--- a/GMW/GMW_Term/WebUserControls/mod_btnUdc.ascx.cs
+++ b/GMW/GMW_Term/WebUserControls/mod_btnUdc.ascx.cs
@@ -311,8 +311,16 @@ namespace GMW_Term.WebUserControls
}
catch
{ }
- // se NON CONSUMATO e la posizione prevede una delibera mostro il relativo pulsante...
- if (!consumato && codTipoDelibera != "")
+ // controllo NON sia in OVAS
+ bool isInOvas = false;
+ try
+ {
+ isInOvas = (MagClass.magazzino.taPosUdcCorr.getByUDC(_UDC).Rows.Count > 0);
+ }
+ catch
+ { }
+ // se NON CONSUMATO, la posizione prevede una delibera e NON E' in OVAS mostro il relativo pulsante...
+ if (!consumato && codTipoDelibera != "" && !isInOvas)
{
switch (codTipoDelibera) //!!!OCCHIO HARD CODED!!!
{